pub fn status() -> Option<BatteryStatus>Expand description
Read the current battery status via the platform’s native API. Returns None when there is no
battery API for the platform, or the device has no battery.
pub fn status() -> Option<BatteryStatus>Read the current battery status via the platform’s native API. Returns None when there is no
battery API for the platform, or the device has no battery.